%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This work is licensed under a Creative Commons Attribution 4.0
% International License. http://creativecommons.org/licenses/by/4.0/
% The authors do not assume liability for errors contained in or for
% damages arising from the use of the software.
%
% CC-BY (4.0) Oliver Taubmann (oliver.taubmann@fau.de), 2015
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function ess = compute_es(profs, prof_length)
% Compute edge sharpness values for profiles

num_profiles = size(profs, 1);
num_samples  = size(profs, 2);

pixel_dists = linspace(-prof_length/2, prof_length/2, num_samples);

ess = zeros(size(profs, 1), 1);

for i = 1:num_profiles
    
    fst_half = 1:num_samples/2;
    snd_half = num_samples/2+1:num_samples;
    
    % we assume rising edges below -- reverse profile
    % here if it appears to be a falling edge instead
    if (mean(profs(i, fst_half)) > mean(profs(i, snd_half)))
        profs(i, :) = profs(i, end:-1:1);
    end
    
    [~, start_idx] = min(profs(i, fst_half(end:-1:1))); % search from back...
    [~, end_idx]   = max(profs(i, snd_half));
    start_idx = length(fst_half) - start_idx + 1; % ... and reverse
    end_idx   = end_idx + num_samples/2;
    
    fit_range = pixel_dists(start_idx:end_idx);
    
    slope = cov(fit_range, profs(i, start_idx:end_idx));
    slope = slope(1, 2); % xy covariance from 2-by-2 covariance matrix
    slope = slope / var(fit_range);

    ess(i) = slope;
end

end